[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Commits] r17402 - in /fsf/trunk/ports: ./ sysdeps/unix/sysv/linux/alpha/ sysdeps/unix/sysv/linux/alpha/bits/ sysdeps/unix/sysv/linux/...



Author: eglibc
Date: Mon Mar  5 00:01:51 2012
New Revision: 17402

Log:
Import glibc-ports-mainline for 2012-03-05

Modified:
    fsf/trunk/ports/ChangeLog.alpha
    fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/siginfo.h
    fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/socket.h
    fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/ioperm.c
    fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/nptl/bits/pthreadtypes.h

Modified: fsf/trunk/ports/ChangeLog.alpha
==============================================================================
--- fsf/trunk/ports/ChangeLog.alpha (original)
+++ fsf/trunk/ports/ChangeLog.alpha Mon Mar  5 00:01:51 2012
@@ -1,3 +1,23 @@
+2012-03-04  Richard Henderson  <rth@xxxxxxxxxxx>
+
+	* sysdeps/unix/sysv/linux/alpha/ioperm.c (inline_sethae): Mark
+	as always_inline.
+
+2012-03-04  Richard Henderson  <rth@xxxxxxxxxxx>
+
+	* sysdeps/unix/sysv/linux/alpha/bits/socket.h (recvmmsg): Only
+	declare if __USE_GNU.
+	(sendmmsg): Add declaration.
+
+2012-03-04  Richard Henderson  <rth@xxxxxxxxxxx>
+
+	* sysdeps/unix/sysv/linux/alpha/bits/siginfo.h: Don't name the
+	siginfo_t struct.  Add forward declaration of pthread_attr_t;
+	use it in sigevent.
+	* sysdeps/unix/sysv/linux/alpha/nptl/bits/pthreadtypes.h
+	(pthread_attr_t): Add union tag to pthread_attr_t; only define
+	typedef if not already defined.
+
 2012-02-21  Richard Henderson  <rth@xxxxxxxxxxx>
 
 	* sysdeps/unix/sysv/linux/alpha/bits/epoll.h: New file.

Modified: fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/siginfo.h
==============================================================================
--- fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/siginfo.h (original)
+++ fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/siginfo.h Mon Mar  5 00:01:51 2012
@@ -1,5 +1,5 @@
 /* siginfo_t, sigevent and constants.  Linux/Alpha version.
-   Copyright (C) 1997-2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1997-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -42,7 +42,7 @@
 # define __SI_MAX_SIZE     128
 # define __SI_PAD_SIZE     ((__SI_MAX_SIZE / sizeof (int)) - 4)
 
-typedef struct siginfo
+typedef struct
   {
     int si_signo;		/* Signal number.  */
     int si_errno;		/* If non-zero, an errno value associated with
@@ -260,6 +260,12 @@
 # define __SIGEV_MAX_SIZE	64
 # define __SIGEV_PAD_SIZE	((__SIGEV_MAX_SIZE / sizeof (int)) - 4)
 
+/* Forward declaration.  */
+#ifndef __have_pthread_attr_t
+typedef union pthread_attr_t pthread_attr_t;
+# define __have_pthread_attr_t  1
+#endif
+
 typedef struct sigevent
   {
     sigval_t sigev_value;
@@ -277,7 +283,7 @@
 	struct
 	  {
 	    void (*_function) (sigval_t);	/* Function to start.  */
-	    void *_attribute;			/* Really pthread_attr_t.  */
+	    pthread_attr_t *_attribute;		/* Thread attributes.  */
 	  } _sigev_thread;
       } _sigev_un;
   } sigevent_t;

Modified: fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/socket.h
==============================================================================
--- fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/ioperm.c (original)
+++ fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/ioperm.c Mon Mar  5 00:01:51 2012
@@ -220,7 +220,7 @@
     return io.base + (port << 7) + ((size - 1) << 5);
 }
 
-static inline void
+static inline __attribute__((always_inline)) void
 inline_sethae (unsigned long int addr, ioswizzle_t ioswiz)
 {
   if (ioswiz == IOSWIZZLE_SPARSE)

Modified: fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/nptl/bits/pthreadtypes.h
==============================================================================
--- fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/nptl/bits/pthreadtypes.h (original)
+++ fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/nptl/bits/pthreadtypes.h Mon Mar  5 00:01:51 2012
@@ -1,5 +1,5 @@
 /* Machine-specific pthread type layouts.  Alpha version.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2003-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -36,12 +36,15 @@
 typedef unsigned long int pthread_t;
 
 
-typedef union
+union pthread_attr_t
 {
   char __size[__SIZEOF_PTHREAD_ATTR_T];
   long int __align;
-} pthread_attr_t;
-
+};
+#ifndef __have_pthread_attr_t
+typedef union pthread_attr_t pthread_attr_t;
+# define __have_pthread_attr_t	1
+#endif
 
 typedef struct __pthread_internal_list
 {

_______________________________________________
Commits mailing list
Commits@xxxxxxxxxx
http://eglibc.org/cgi-bin/mailman/listinfo/commits
--- fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/socket.h (original)
+++ fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/bits/socket.h Mon Mar  5 00:01:51 2012
@@ -1,6 +1,5 @@
 /* System-specific socket constants and types.  Linux version.
-   Copyright (C) 1991, 1992, 1994-2001, 2004, 2006, 2007, 2008, 2009, 2010
-   Free Software Foundation, Inc.
+   Copyright (C) 1991-2012 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -417,14 +416,22 @@
 
 __BEGIN_DECLS
 
 /* Receive a message as described by MESSAGE from socket FD.
    Returns the number of bytes read or -1 for errors.
-
    This function is a cancellation point and therefore not marked with
    __THROW.  */
 extern int recvmmsg (int __fd, struct mmsghdr *__vmessages,
 		     unsigned int __vlen, int __flags,
-		     __const struct timespec *__tmo);
+		     const struct timespec *__tmo);
+
+/* Send a VLEN messages as described by VMESSAGES to socket FD.
+   Return the number of datagrams successfully written or -1 for errors.
+   This function is a cancellation point and therefore not marked with
+   __THROW.  */
+extern int sendmmsg (int __fd, struct mmsghdr *__vmessages,
+		     unsigned int __vlen, int __flags);
+#endif
 
 __END_DECLS
 
@@ -417,14 +416,22 @@
 __BEGIN_DECLS
 
-/* Receive a message as described by MESSAGE from socket FD.
+#ifdef __USE_GNU
+/* Receive up to VLEN messages as described by VMESSAGES from socket FD.
    Returns the number of bytes read or -1 for errors.

Modified: fsf/trunk/ports/sysdeps/unix/sysv/linux/alpha/ioperm.c
==============================================================================